@@ -1,7 +1,7 @@
 package TableData::Object::aohos;
 
 our $DATE = '2016-01-11'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 use 5.010001;
 use strict;
@@ -68,28 +68,49 @@ sub rows_as_aohos {
     $self->{data};
 }
 
+sub uniq_col_names {
+    my $self = shift;
+
+    my @res;
+  COL:
+    for my $col (sort keys %{$self->{cols_by_name}}) {
+        my %mem;
+        for my $row (@{$self->{data}}) {
+            next COL unless defined $row->{$col};
+            next COL if $mem{ $row->{$col} }++;
+        }
+        push @res, $col;
+    }
+    @res;
+}
+
 sub const_col_names {
     my $self = shift;
 
-    my $res = [];
+    my @res;
   COL:
     for my $col (sort keys %{$self->{cols_by_name}}) {
         my $i = -1;
         my $val;
+        my $val_undef;
         for my $row (@{$self->{data}}) {
             next COL unless exists $row->{$col};
             $i++;
             if ($i == 0) {
                 $val = $row->{$col};
+                $val_undef = 1 unless defined $val;
             } else {
-                next COL unless
-                    (!defined($val) && !defined($row->{$col})) ||
-                    ( defined($val) &&  defined($row->{$col}) && $val eq $row->{$col});
+                if ($val_undef) {
+                    next COL if defined $row->{$col};
+                } else {
+                    next COL unless defined $row->{$col};
+                    next COL unless $val eq $row->{$col};
+                }
             }
         }
-        push @$res, $col;
+        push @res, $col;
     }
-    $res;
+    @res;
 }
 
 1;
@@ -107,7 +128,7 @@ TableData::Object::aohos - Manipulate array of hashes-of-scalars via table objec
 
 =head1 VERSION
 
-This document describes version 0.07 of TableData::Object::aohos (from Perl distribution TableData-Object), released on 2016-01-11.
+This document describes version 0.08 of TableData::Object::aohos (from Perl distribution TableData-Object), released on 2016-01-11.
 
 =head1 SYNOPSIS
 
