@@ -1,7 +1,7 @@
 package TableData::Object::aos;
 
 our $DATE = '2016-01-11'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 use 5.010001;
 use strict;
@@ -33,6 +33,39 @@ sub rows_as_aohos {
     [map {{elem=>$_}} @{ $self->{data} }];
 }
 
+sub uniq_col_names {
+    my $self = shift;
+    my %mem;
+    for (@{$self->{data}}) {
+        return () unless defined;
+        return () if $mem{$_}++;
+    }
+    ('elem');
+}
+
+sub const_col_names {
+    my $self = shift;
+
+    my $i = -1;
+    my $val;
+    my $val_undef;
+    for (@{$self->{data}}) {
+        $i++;
+        if ($i == 0) {
+            $val = $_;
+            $val_undef = 1 unless defined $val;
+        } else {
+            if ($val_undef) {
+                return () if defined;
+            } else {
+                return () unless defined;
+                return () unless $val eq $_;
+            }
+        }
+    }
+    ('elem');
+}
+
 1;
 # ABSTRACT: Manipulate array of scalars via table object
 
@@ -48,7 +81,7 @@ TableData::Object::aos - Manipulate array of scalars via table object
 
 =head1 VERSION
 
-This document describes version 0.07 of TableData::Object::aos (from Perl distribution TableData-Object), released on 2016-01-11.
+This document describes version 0.08 of TableData::Object::aos (from Perl distribution TableData-Object), released on 2016-01-11.
 
 =head1 SYNOPSIS
 
